@@ -72,7 +72,7 @@ sub descend
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
-	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	say "\nNow in Sim::OPT::Descend.\n";
@@ -282,7 +282,7 @@ sub descend
 				$countel++;
 			}
 		} 
-		#say TOSHELL "dump(SELECTEDMIXED \@containernames): " . dump(@containernames); 
+		say TOSHELL "dump(SELECTEDMIXED \@containernames): " . dump(@containernames); 
 			
 		my @containertwo;
 		my @containerthree;
@@ -309,8 +309,8 @@ sub descend
 				push (@maxes, "NOTHING1");
 			}
 					
-			#print $_outfile_ "MAXES: " . Dumper(@maxes) . "\n";
-			#print $_outfile_ "DUMPCOLUMN: " . Dumper(@column) . "\n";
+			print $_outfile_ "MAXES: " . Dumper(@maxes) . "\n";
+			print $_outfile_ "DUMPCOLUMN: " . Dumper(@column) . "\n";
 			
 			foreach my $el (@column)
 			{
@@ -339,8 +339,8 @@ sub descend
 			foreach $eltref (@containertwo)
 			{
 				my @col =  @{$eltref};
-				my $max = max(@col); #print $_outfile_ "MAX: $max\n";
-				my $min = min(@col); #print $_outfile_ "MIN: $min\n";
+				my $max = max(@col); print $_outfile_ "MAX: $max\n";
+				my $min = min(@col); print $_outfile_ "MIN: $min\n";
 				my $floordistance = ($max - $min);
 				my $range = ( $min / $max);
 				my $el = $col[$countline];
